@@ -21,6 +21,12 @@ def name():
     return getname(f)
 
 
+class Id:
+    def __init__(self, name, title, mac_address):
+        self.name = name
+        self.title = title
+        self.mac_address = mac_address
+
 def id():
     f = footprint.footprint()
     name = getname(f)
@@ -29,9 +35,5 @@ def id():
     mac_address = getmac()
 
     title = config.titles[name]
-    id = {
-        'name': name,
-        'title': title,
-        'mac_address': mac_address
-    }
+    id = Id(name, title, mac_address)
     return id
\ No newline at end of file
